@@ -25,7 +25,7 @@ from maleo.schemas.operation.resource import (
     CreateSingleResourceOperation,
     ReadSingleResourceOperation,
 )
-from maleo.schemas.resource import ResourceIdentifier
+from maleo.schemas.resource import ResourceIdentifier, AggregateField
 from maleo.schemas.response import (
     SingleDataResponse,
     CreateSingleDataResponse,
@@ -38,13 +38,15 @@ from maleo.types.misc import OptionalPathOrString
 from maleo.types.string import ListOfStrings
 from maleo.types.uuid import OptionalUUID
 from maleo.utils.exception import extract_details
-from .base import RESOURCE as BASE_RESOURCE, GoogleClientManager
+from .base import GOOGLE_RESOURCE, GoogleClientManager
 from .types import OptionalCredentials
 
 
-RESOURCE = deepcopy(BASE_RESOURCE)
-RESOURCE.identifiers.append(
-    ResourceIdentifier(key="secret", name="Secret", slug="secret")
+SECRET_MANAGER_RESOURCE = deepcopy(GOOGLE_RESOURCE)
+SECRET_MANAGER_RESOURCE.identifiers.append(
+    ResourceIdentifier(
+        key="secret_manager", name="Secret Manager", slug="secret-manager"
+    )
 )
 
 
@@ -82,8 +84,8 @@ class GoogleSecretManager(GoogleClientManager):
         credentials_path: OptionalPathOrString = None,
     ) -> None:
         super().__init__(
-            "google-secret-manager",
-            "GoogleSecretManager",
+            SECRET_MANAGER_RESOURCE.aggregate(),
+            SECRET_MANAGER_RESOURCE.aggregate(AggregateField.NAME),
             log_config,
             application_context,
             credentials,
@@ -112,7 +114,7 @@ class GoogleSecretManager(GoogleClientManager):
             create_type=ResourceOperationCreateType.NEW,
         )
 
-        resource = deepcopy(RESOURCE)
+        resource = deepcopy(SECRET_MANAGER_RESOURCE)
         resource.details = {"name": name}
 
         executed_at = datetime.now(tz=timezone.utc)
@@ -172,7 +174,7 @@ class GoogleSecretManager(GoogleClientManager):
                 id=operation_id,
                 context=self._operation_context,
                 action=operation_action,
-                resource=RESOURCE,
+                resource=resource,
                 timestamp=Timestamp.completed_now(executed_at),
                 summary=f"Successfully added new secret '{name}' version",
                 connection_context=connection_context,
@@ -251,7 +253,7 @@ class GoogleSecretManager(GoogleClientManager):
         operation_id = operation_id if operation_id is not None else uuid4()
         operation_action = ReadResourceOperationAction()
 
-        resource = deepcopy(RESOURCE)
+        resource = deepcopy(SECRET_MANAGER_RESOURCE)
         resource.details = {"name": name, "version": version}
 
         value_type = FORMAT_TYPE_MAP.get(format, None)
@@ -371,7 +373,7 @@ class GoogleSecretManager(GoogleClientManager):
                 id=operation_id,
                 context=self._operation_context,
                 action=operation_action,
-                resource=RESOURCE,
+                resource=resource,
                 timestamp=Timestamp.completed_now(executed_at),
                 summary=f"Successfully retrieved secret '{name}' with version '{version}'",
                 connection_context=connection_context,
