@@ -43,13 +43,13 @@ from maleo.types.misc import OptionalPathOrString
 from maleo.types.string import OptionalString
 from maleo.types.uuid import OptionalUUID
 from maleo.utils.exception import extract_details
-from .base import RESOURCE as BASE_RESOURCE, GoogleClientManager
+from .base import GOOGLE_RESOURCE, GoogleClientManager
 from .types import OptionalCredentials
 
 
-RESOURCE = deepcopy(BASE_RESOURCE)
-RESOURCE.identifiers.append(
-    ResourceIdentifier(key="storage", name="Storage", slug="storage")
+CLOUD_STORAGE_RESOURCE = deepcopy(GOOGLE_RESOURCE)
+CLOUD_STORAGE_RESOURCE.identifiers.append(
+    ResourceIdentifier(key="cloud_storage", name="Cloud Storage", slug="cloud-storage")
 )
 
 
@@ -69,8 +69,8 @@ class GoogleCloudStorage(GoogleClientManager):
         redis: RedisManager,
     ) -> None:
         super().__init__(
-            "google-cloud-storage",
-            "GoogleCloudStorage",
+            CLOUD_STORAGE_RESOURCE.aggregate(),
+            CLOUD_STORAGE_RESOURCE.aggregate(AggregateField.NAME),
             log_config,
             application_context,
             credentials,
@@ -99,7 +99,7 @@ class GoogleCloudStorage(GoogleClientManager):
 
         self._redis = redis
         self._namespace = build_cache_namespace(
-            RESOURCE.aggregate(AggregateField.KEY),
+            CLOUD_STORAGE_RESOURCE.aggregate(AggregateField.KEY, sep=":"),
             base=self._application_context.key,
             client=self._key,
             origin=CacheOrigin.CLIENT,
@@ -145,7 +145,7 @@ class GoogleCloudStorage(GoogleClientManager):
         else:
             blob_name = f"{root_location_override}/{location}"
 
-        resource = deepcopy(RESOURCE)
+        resource = deepcopy(CLOUD_STORAGE_RESOURCE)
         resource.details = {"location": location, "blob_name": blob_name}
 
         try:
@@ -236,7 +236,7 @@ class GoogleCloudStorage(GoogleClientManager):
         else:
             blob_name = f"{root_location_override}/{location}"
 
-        resource = deepcopy(RESOURCE)
+        resource = deepcopy(CLOUD_STORAGE_RESOURCE)
         resource.details = {"location": location, "blob_name": blob_name}
 
         if use_cache:
